Class: String
Overview
:nodoc:
Instance Method Summary collapse
-
#blank? ⇒ TrueClass, FalseClass
Strips out whitespace then tests if the string is empty.
Instance Method Details
#blank? ⇒ TrueClass, FalseClass
Strips out whitespace then tests if the string is empty.
56 57 58 |
# File 'lib/multi_xml/core_extensions.rb', line 56 def blank? strip.empty? end |